@@ -1,5 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="de">
+<!DOCTYPE TS>
+<TS version="2.1" language="de">
 <context>
     <name>LogWidget</name>
     <message>
@@ -61,271 +62,272 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="47"/>
+        <location filename="../mainwindow.cpp" line="55"/>
         <source>Event Log</source>
         <translation>Protokoll</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="56"/>
-        <source>Unmatched</source>
-        <translation>Unpassend</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="63"/>
+        <location filename="../mainwindow.cpp" line="71"/>
         <source>&amp;New...</source>
         <translation>&amp;Neu...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="68"/>
+        <location filename="../mainwindow.cpp" line="76"/>
         <source>&amp;Clone</source>
         <translation>&amp;Duplizieren</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="73"/>
+        <location filename="../mainwindow.cpp" line="81"/>
         <source>&amp;Rename...</source>
         <translation>&amp;Umbenennen...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="78"/>
+        <location filename="../mainwindow.cpp" line="86"/>
         <source>&amp;Delete...</source>
         <translation>&amp;Löschen...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="198"/>
+        <location filename="../mainwindow.cpp" line="209"/>
         <source>About %1</source>
         <translation>Über %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="212"/>
-        <source>Add MIDI Map</source>
-        <translation>Neue Route</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="213"/>
-        <source>Map %1</source>
-        <translation>Route %1</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="297"/>
+        <location filename="../mainwindow.cpp" line="308"/>
         <source>New Name</source>
         <translation>Neuer Name</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="314"/>
+        <location filename="../mainwindow.cpp" line="324"/>
         <source>Delete &quot;%1&quot;?</source>
         <translation>&quot;%1&quot; löschen?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="427"/>
+        <location filename="../mainwindow.cpp" line="387"/>
+        <location filename="../mainwindow.cpp" line="438"/>
         <source>QMidiRoute files</source>
         <translation>QMidiRoute-Dateien</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="140"/>
+        <location filename="../mainwindow.cpp" line="148"/>
         <source>&amp;About %1...</source>
         <translation>&amp;Über %1...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="64"/>
-        <source>Ctrl+N</source>
-        <comment>Map|New</comment>
-        <translation>Strg+N</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="69"/>
-        <source>Ctrl+C</source>
-        <comment>Map|Clone</comment>
-        <translation>Strg+C</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="74"/>
-        <source>Ctrl+R</source>
-        <comment>Map|Rename</comment>
-        <translation>Strg+U</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="79"/>
-        <source>Ctrl+Del</source>
-        <comment>Map|Delete</comment>
-        <translation>Strg+Entf</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="123"/>
+        <location filename="../mainwindow.cpp" line="131"/>
         <source>&amp;File</source>
         <translation>&amp;Datei</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="125"/>
-        <source>&amp;Map</source>
-        <translation>&amp;Route</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="126"/>
+        <location filename="../mainwindow.cpp" line="134"/>
         <source>&amp;Help</source>
         <translation>&amp;Hilfe</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="88"/>
+        <location filename="../mainwindow.cpp" line="96"/>
         <source>&amp;Open...</source>
         <translation>&amp;Öffnen...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="93"/>
+        <location filename="../mainwindow.cpp" line="64"/>
+        <source>&amp;Unmatched</source>
+        <translation>&amp;Unpassend</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="72"/>
+        <source>Ctrl+N</source>
+        <comment>Rule|New</comment>
+        <translation>Strg+N</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="73"/>
+        <source>Add new rule</source>
+        <translation>Neue MIDI-Route hinzufügen</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="77"/>
+        <source>Ctrl+C</source>
+        <comment>Rule|Clone</comment>
+        <translation>Strg+C</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="78"/>
+        <source>Duplicate selected rule</source>
+        <translation>Ausgewählte MIDI-Route duplizieren</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="82"/>
+        <source>Ctrl+R</source>
+        <comment>Rule|Rename</comment>
+        <translation>Strg+U</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="83"/>
+        <source>Rename selected rule</source>
+        <translation>Ausgewählte MIDI-Route umbenennen</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="87"/>
+        <source>Ctrl+Del</source>
+        <comment>Rule|Delete</comment>
+        <translation>Strg+Entf</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="88"/>
+        <source>Delete selected rule</source>
+        <translation>Ausgewählte MIDI-Route löschen</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="101"/>
         <source>&amp;Save</source>
         <translation>&amp;Speichern</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="98"/>
+        <location filename="../mainwindow.cpp" line="106"/>
         <source>Save &amp;as...</source>
         <translation>Speichern &amp;unter...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="103"/>
+        <location filename="../mainwindow.cpp" line="111"/>
         <source>&amp;Quit</source>
         <translation>&amp;Beenden</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="104"/>
+        <location filename="../mainwindow.cpp" line="112"/>
         <source>Ctrl+Q</source>
         <comment>File|Quit</comment>
         <translation>Strg+Q</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="471"/>
+        <location filename="../mainwindow.cpp" line="133"/>
+        <source>&amp;Rule</source>
+        <translation>&amp;Route</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="223"/>
+        <source>Add rule</source>
+        <translation>Neue MIDI-Route hinzufügen</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="224"/>
+        <source>Rule %1</source>
+        <translation>Route %1</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="482"/>
         <source>Unnamed file was changed.
 Save changes?</source>
         <translation>Die unbenannte Datei wurde geändert.
 Änderungen speichern?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="474"/>
+        <location filename="../mainwindow.cpp" line="484"/>
         <source>File &apos;%1&apos; was changed.
 Save changes?</source>
         <translation>Die Datei &apos;%1&apos; wurde geändert.
 Änderungen speichern?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="477"/>
+        <location filename="../mainwindow.cpp" line="488"/>
         <source>Save changes</source>
         <translation>Änderungen speichern</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="142"/>
+        <location filename="../mainwindow.cpp" line="150"/>
         <source>&amp;About Qt...</source>
         <translation>Über &amp;Qt...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="203"/>
+        <location filename="../mainwindow.cpp" line="214"/>
         <source>About Qt</source>
         <translation>Über Qt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="393"/>
+        <location filename="../mainwindow.cpp" line="404"/>
         <source>Could not read from file &apos;%1&apos;.</source>
         <translation>Konnte Datei &apos;%1&apos; nicht lesen.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="454"/>
+        <location filename="../mainwindow.cpp" line="465"/>
         <source>Could not write to file &apos;%1&apos;.</source>
         <translation>Konnte Datei &apos;%1&apos; nicht schreiben.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="375"/>
+        <location filename="../mainwindow.cpp" line="386"/>
         <source>Open MIDI route map file</source>
         <translation>MIDI-Routendatei öffnen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="426"/>
+        <location filename="../mainwindow.cpp" line="437"/>
         <source>Save MIDI route map file</source>
         <translation>MIDI-Routendatei speichern</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="83"/>
+        <location filename="../mainwindow.cpp" line="91"/>
         <source>&amp;New</source>
         <translation>&amp;Neu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="124"/>
+        <location filename="../mainwindow.cpp" line="132"/>
         <source>&amp;View</source>
         <translation>&amp;Ansicht</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="118"/>
+        <location filename="../mainwindow.cpp" line="126"/>
         <source>Ctrl+L</source>
         <comment>View|Event Log</comment>
         <translation>Strg+L</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="117"/>
+        <location filename="../mainwindow.cpp" line="125"/>
         <source>&amp;Event Log</source>
         <translation>&amp;Protokoll</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="150"/>
+        <location filename="../mainwindow.cpp" line="158"/>
         <source>&amp;Toolbar</source>
         <translation>&amp;Werkzeugleiste</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="163"/>
+        <location filename="../mainwindow.cpp" line="171"/>
         <source>Ctrl+T</source>
         <comment>View|Toolbar</comment>
         <translation>Strg+T</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="65"/>
-        <source>Add new MIDI route</source>
-        <translation>Neue MIDI-Route hinzufügen</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="70"/>
-        <source>Duplicate selected MIDI route</source>
-        <translation>Ausgewählte MIDI-Route duplizieren</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="75"/>
-        <source>Rename selected MIDI route</source>
-        <translation>Ausgewählte MIDI-Route umbenennen</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="85"/>
+        <location filename="../mainwindow.cpp" line="93"/>
         <source>Create new MIDI route file</source>
         <translation>Neue MIDI-Routendatei anlegen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="90"/>
+        <location filename="../mainwindow.cpp" line="98"/>
         <source>Open MIDI route file</source>
         <translation>MIDI-Routendatei öffnen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="95"/>
+        <location filename="../mainwindow.cpp" line="103"/>
         <source>Save current MIDI route file</source>
         <translation>Aktuelle MIDI-Routendatei speichern</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="100"/>
+        <location filename="../mainwindow.cpp" line="108"/>
         <source>Save current MIDI route file with new name</source>
         <translation>Aktuelle MIDI-Routendatei unter neuem Namen speichern</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="105"/>
+        <location filename="../mainwindow.cpp" line="113"/>
         <source>Quit application</source>
         <translation>Anwendung beenden</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="119"/>
+        <location filename="../mainwindow.cpp" line="127"/>
         <source>Show/hide MIDI event log window</source>
         <translation>Protokollfenster anzeigen/verbergen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="164"/>
+        <location filename="../mainwindow.cpp" line="172"/>
         <source>Show/hide toolbar</source>
         <translation>Wergzeugleiste anzeigen/verbergen</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="80"/>
-        <source>Delete selected MIDI route</source>
-        <translation>Ausgewählte MIDI-Route löschen</translation>
-    </message>
 </context>
 <context>
     <name>MapWidget</name>
@@ -365,7 +367,7 @@ Save changes?</source>
         <translation>Controller</translation>
     </message>
     <message>
-        <location filename="../mapwidget.cpp" line="14"/>
+        <location filename="../mapwidget.cpp" line="13"/>
         <source>Pitchbend</source>
         <translation>Pitchbend</translation>
     </message>
@@ -385,11 +387,13 @@ Save changes?</source>
         <translation>&amp;Kanal</translation>
     </message>
     <message>
+        <location filename="../mapwidget.cpp" line="47"/>
         <location filename="../mapwidget.cpp" line="225"/>
         <source>&amp;Note</source>
         <translation>&amp;Note</translation>
     </message>
     <message>
+        <location filename="../mapwidget.cpp" line="64"/>
         <location filename="../mapwidget.cpp" line="226"/>
         <source>&amp;Velocity</source>
         <translation>&amp;Anschlag</translation>
@@ -400,6 +404,9 @@ Save changes?</source>
         <translation>T&amp;yp</translation>
     </message>
     <message>
+        <location filename="../mapwidget.cpp" line="130"/>
+        <location filename="../mapwidget.cpp" line="284"/>
+        <location filename="../mapwidget.cpp" line="291"/>
         <location filename="../mapwidget.cpp" line="301"/>
         <source>N&amp;ote</source>
         <translation>N&amp;ote</translation>
@@ -410,6 +417,7 @@ Save changes?</source>
         <translation>An&amp;schlag</translation>
     </message>
     <message>
+        <location filename="../mapwidget.cpp" line="236"/>
         <location filename="../mapwidget.cpp" line="256"/>
         <source>V&amp;alue</source>
         <translation>W&amp;ert</translation>
@@ -420,6 +428,8 @@ Save changes?</source>
         <translation>P&amp;itch</translation>
     </message>
     <message>
+        <location filename="../mapwidget.cpp" line="281"/>
+        <location filename="../mapwidget.cpp" line="294"/>
         <location filename="../mapwidget.cpp" line="304"/>
         <source>V&amp;elocity</source>
         <translation>Ansc&amp;hlag</translation>
@@ -430,6 +440,7 @@ Save changes?</source>
         <translation>&amp;Wert</translation>
     </message>
     <message>
+        <location filename="../mapwidget.cpp" line="356"/>
         <location filename="../mapwidget.cpp" line="364"/>
         <source>&amp;Value</source>
         <translation>&amp;Wert</translation>
@@ -470,7 +481,7 @@ Save changes?</source>
     <message>
         <location filename="../passwidget.cpp" line="16"/>
         <source>&amp;Send unmatched events to port</source>
-        <translation>&amp;Unpassende Signale senden an Ausgang</translation>
+        <translation>Unpassende &amp;Signale senden an Ausgang</translation>
     </message>
 </context>
 </TS>
