@@ -1,5 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="fr">
+<!DOCTYPE TS>
+<TS version="2.1" language="fr">
 <context>
     <name>LogWidget</name>
     <message>
@@ -61,270 +62,303 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="47"/>
+        <location filename="../mainwindow.cpp" line="55"/>
         <source>Event Log</source>
         <translation>Journal</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="56"/>
         <source>Unmatched</source>
-        <translation>Non-traité</translation>
+        <translation type="obsolete">Non-traité</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="63"/>
+        <location filename="../mainwindow.cpp" line="71"/>
         <source>&amp;New...</source>
         <translation>&amp;Nouveau...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="68"/>
+        <location filename="../mainwindow.cpp" line="72"/>
+        <source>Ctrl+N</source>
+        <comment>Rule|New</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="73"/>
+        <source>Add new rule</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="76"/>
         <source>&amp;Clone</source>
         <translation>&amp;Dupliquer</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="73"/>
+        <location filename="../mainwindow.cpp" line="77"/>
+        <source>Ctrl+C</source>
+        <comment>Rule|Clone</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="78"/>
+        <source>Duplicate selected rule</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="81"/>
         <source>&amp;Rename...</source>
         <translation>&amp;Renommer...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="78"/>
+        <location filename="../mainwindow.cpp" line="82"/>
+        <source>Ctrl+R</source>
+        <comment>Rule|Rename</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="83"/>
+        <source>Rename selected rule</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="86"/>
         <source>&amp;Delete...</source>
         <translation>&amp;Supprimer...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="198"/>
+        <location filename="../mainwindow.cpp" line="87"/>
+        <source>Ctrl+Del</source>
+        <comment>Rule|Delete</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="88"/>
+        <source>Delete selected rule</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="133"/>
+        <source>&amp;Rule</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="209"/>
         <source>About %1</source>
         <translation>A propos de %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="212"/>
         <source>Add MIDI Map</source>
-        <translation>Ajouter Route MIDI</translation>
+        <translation type="obsolete">Ajouter Route MIDI</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="213"/>
         <source>Map %1</source>
-        <translation>Route %1</translation>
+        <translation type="obsolete">Route %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="297"/>
+        <location filename="../mainwindow.cpp" line="308"/>
         <source>New Name</source>
         <translation>Nouveau nom</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="314"/>
+        <location filename="../mainwindow.cpp" line="324"/>
         <source>Delete &quot;%1&quot;?</source>
         <translation>Supprimer &quot;%1&quot;?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="427"/>
+        <location filename="../mainwindow.cpp" line="387"/>
+        <location filename="../mainwindow.cpp" line="438"/>
         <source>QMidiRoute files</source>
         <translation>Fichiers QMidiRoute</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="123"/>
+        <location filename="../mainwindow.cpp" line="131"/>
         <source>&amp;File</source>
         <translation>&amp;Fichier</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="126"/>
+        <location filename="../mainwindow.cpp" line="134"/>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="88"/>
+        <location filename="../mainwindow.cpp" line="96"/>
         <source>&amp;Open...</source>
         <translation>&amp;Ouvrir...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="93"/>
+        <location filename="../mainwindow.cpp" line="64"/>
+        <source>&amp;Unmatched</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="101"/>
         <source>&amp;Save</source>
         <translation>&amp;Enregistrer</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="103"/>
+        <location filename="../mainwindow.cpp" line="111"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="140"/>
+        <location filename="../mainwindow.cpp" line="148"/>
         <source>&amp;About %1...</source>
         <translation>&amp;A propos de %1...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="64"/>
-        <source>Ctrl+N</source>
-        <comment>Map|New</comment>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="69"/>
-        <source>Ctrl+C</source>
-        <comment>Map|Clone</comment>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="74"/>
-        <source>Ctrl+R</source>
-        <comment>Map|Rename</comment>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="79"/>
-        <source>Ctrl+Del</source>
-        <comment>Map|Delete</comment>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="125"/>
         <source>&amp;Map</source>
-        <translation>&amp;Route</translation>
+        <translation type="obsolete">&amp;Route</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="98"/>
+        <location filename="../mainwindow.cpp" line="106"/>
         <source>Save &amp;as...</source>
         <translation>Enregistrer &amp;sous...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="104"/>
+        <location filename="../mainwindow.cpp" line="112"/>
         <source>Ctrl+Q</source>
         <comment>File|Quit</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="471"/>
+        <location filename="../mainwindow.cpp" line="223"/>
+        <source>Add rule</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="224"/>
+        <source>Rule %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="482"/>
         <source>Unnamed file was changed.
 Save changes?</source>
         <translation>Le fichier sans nom a été modifié.
 Enregistrer les modifications?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="474"/>
+        <location filename="../mainwindow.cpp" line="484"/>
         <source>File &apos;%1&apos; was changed.
 Save changes?</source>
         <translation>Le fichier &apos;%1&apos; a été modifié.
 Enregistrer les modifications?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="477"/>
+        <location filename="../mainwindow.cpp" line="488"/>
         <source>Save changes</source>
         <translation>Enregistrer les modifications</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="142"/>
+        <location filename="../mainwindow.cpp" line="150"/>
         <source>&amp;About Qt...</source>
         <translation>&amp;A propos de Qt...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="203"/>
+        <location filename="../mainwindow.cpp" line="214"/>
         <source>About Qt</source>
         <translation>A propos de Qt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="393"/>
+        <location filename="../mainwindow.cpp" line="404"/>
         <source>Could not read from file &apos;%1&apos;.</source>
         <translation>Erreur lors de la lecture du fichier &apos;%1&apos;.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="454"/>
+        <location filename="../mainwindow.cpp" line="465"/>
         <source>Could not write to file &apos;%1&apos;.</source>
         <translation>Erreur lors de l&apos;écriture dans &apos;%1&apos;.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="375"/>
+        <location filename="../mainwindow.cpp" line="386"/>
         <source>Open MIDI route map file</source>
         <translation>Ouvrir un fichier de routage</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="426"/>
+        <location filename="../mainwindow.cpp" line="437"/>
         <source>Save MIDI route map file</source>
         <translation>Enregistrer le fichier de routage</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="83"/>
+        <location filename="../mainwindow.cpp" line="91"/>
         <source>&amp;New</source>
         <translation>&amp;Nouveau</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="124"/>
+        <location filename="../mainwindow.cpp" line="132"/>
         <source>&amp;View</source>
         <translation>&amp;Vue</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="118"/>
+        <location filename="../mainwindow.cpp" line="126"/>
         <source>Ctrl+L</source>
         <comment>View|Event Log</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="117"/>
+        <location filename="../mainwindow.cpp" line="125"/>
         <source>&amp;Event Log</source>
         <translation>&amp;Journal</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="150"/>
+        <location filename="../mainwindow.cpp" line="158"/>
         <source>&amp;Toolbar</source>
         <translation>Barre d&apos;outils &amp;contrôle</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="163"/>
+        <location filename="../mainwindow.cpp" line="171"/>
         <source>Ctrl+T</source>
         <comment>View|Toolbar</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="65"/>
         <source>Add new MIDI route</source>
-        <translation>Ajouter une nouvelle route MIDI</translation>
+        <translation type="obsolete">Ajouter une nouvelle route MIDI</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="70"/>
         <source>Duplicate selected MIDI route</source>
-        <translation>Dupliquer la route MIDI sélectionnée</translation>
+        <translation type="obsolete">Dupliquer la route MIDI sélectionnée</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="75"/>
         <source>Rename selected MIDI route</source>
-        <translation>Renommer la route MIDI sélectionnée</translation>
+        <translation type="obsolete">Renommer la route MIDI sélectionnée</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="85"/>
+        <location filename="../mainwindow.cpp" line="93"/>
         <source>Create new MIDI route file</source>
         <translation>Créer un nouveau fichier de routage MIDI</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="90"/>
+        <location filename="../mainwindow.cpp" line="98"/>
         <source>Open MIDI route file</source>
         <translation>Ouvrir un fichier de routage MIDI</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="95"/>
+        <location filename="../mainwindow.cpp" line="103"/>
         <source>Save current MIDI route file</source>
         <translation>Enregistrer le fichier de routage MIDI actuel</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="100"/>
+        <location filename="../mainwindow.cpp" line="108"/>
         <source>Save current MIDI route file with new name</source>
         <translation>Enregistrer le fichier de routage MIDI avec un nouveau nom</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="105"/>
+        <location filename="../mainwindow.cpp" line="113"/>
         <source>Quit application</source>
         <translation>Quitter l&apos;application</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="119"/>
+        <location filename="../mainwindow.cpp" line="127"/>
         <source>Show/hide MIDI event log window</source>
         <translation>Afficher/cacher le fenêtre de journal </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="164"/>
+        <location filename="../mainwindow.cpp" line="172"/>
         <source>Show/hide toolbar</source>
         <translation>Affichier/cacher la barre d&apos;outils</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="80"/>
         <source>Delete selected MIDI route</source>
-        <translation>Supprimer la route MIDI sélectionnée</translation>
+        <translation type="obsolete">Supprimer la route MIDI sélectionnée</translation>
     </message>
 </context>
 <context>
@@ -360,7 +394,7 @@ Enregistrer les modifications?</translation>
         <translation>Contrôleur</translation>
     </message>
     <message>
-        <location filename="../mapwidget.cpp" line="14"/>
+        <location filename="../mapwidget.cpp" line="13"/>
         <source>Pitchbend</source>
         <translation></translation>
     </message>
@@ -380,11 +414,13 @@ Enregistrer les modifications?</translation>
         <translation>&amp;Canal</translation>
     </message>
     <message>
+        <location filename="../mapwidget.cpp" line="47"/>
         <location filename="../mapwidget.cpp" line="225"/>
         <source>&amp;Note</source>
         <translation>&amp;Note</translation>
     </message>
     <message>
+        <location filename="../mapwidget.cpp" line="64"/>
         <location filename="../mapwidget.cpp" line="226"/>
         <source>&amp;Velocity</source>
         <translation>&amp;Vélocité</translation>
@@ -400,6 +436,9 @@ Enregistrer les modifications?</translation>
         <translation></translation>
     </message>
     <message>
+        <location filename="../mapwidget.cpp" line="130"/>
+        <location filename="../mapwidget.cpp" line="284"/>
+        <location filename="../mapwidget.cpp" line="291"/>
         <location filename="../mapwidget.cpp" line="301"/>
         <source>N&amp;ote</source>
         <translation></translation>
@@ -410,6 +449,7 @@ Enregistrer les modifications?</translation>
         <translation>Vé&amp;locité</translation>
     </message>
     <message>
+        <location filename="../mapwidget.cpp" line="236"/>
         <location filename="../mapwidget.cpp" line="256"/>
         <source>V&amp;alue</source>
         <translation>V&amp;aleur</translation>
@@ -420,6 +460,8 @@ Enregistrer les modifications?</translation>
         <translation></translation>
     </message>
     <message>
+        <location filename="../mapwidget.cpp" line="281"/>
+        <location filename="../mapwidget.cpp" line="294"/>
         <location filename="../mapwidget.cpp" line="304"/>
         <source>V&amp;elocity</source>
         <translation>V&amp;élocité</translation>
@@ -430,6 +472,7 @@ Enregistrer les modifications?</translation>
         <translation>Val&amp;eur</translation>
     </message>
     <message>
+        <location filename="../mapwidget.cpp" line="356"/>
         <location filename="../mapwidget.cpp" line="364"/>
         <source>&amp;Value</source>
         <translation>&amp;Valeur</translation>
